@@ -1,23 +1,9 @@
 /*
-    Copyright 2010 Rafael Fernández López <ereslibre@kde.org>
-              2010 Lukas Tinkl <ltinkl@redhat.com>
-              2011 Matej Laitl <matej@laitl.cz>
+    SPDX-FileCopyrightText: 2010 Rafael Fernández López <ereslibre@kde.org>
+    SPDX-FileCopyrightText: 2010 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2011 Matej Laitl <matej@laitl.cz>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "udevportablemediaplayer.h"
@@ -102,11 +88,7 @@ QStringList PortableMediaPlayer::supportedProtocols() const
         return QStringList();
     }
     QString value = readMpiValue(mpiFile, QString("Device"), QString("AccessProtocol"));
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    return value.split(QChar(';'), QString::SkipEmptyParts);
-#else
     return value.split(QChar(';'), Qt::SkipEmptyParts);
-#endif
 }
 
 QStringList PortableMediaPlayer::supportedDrivers(QString protocol) const
