@@ -1,23 +1,9 @@
 /*
-    Copyright 2009 Pino Toscano <pino@kde.org>
-    Copyright 2010, 2012, 2015 Lukáš Tinkl <ltinkl@redhat.com>
-    Copyright 2014 Kai Uwe Broulik <kde@privat.broulik.de>
+    SPDX-FileCopyrightText: 2009 Pino Toscano <pino@kde.org>
+    SPDX-FileCopyrightText: 2010, 2012, 2015 Lukáš Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2014 Kai Uwe Broulik <kde@privat.broulik.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "upowerbattery.h"
@@ -244,59 +230,59 @@ void Battery::slotChanged()
         updateCache();
 
         if (old_isPresent != m_isPresent) {
-            emit presentStateChanged(m_isPresent, m_device.data()->udi());
+            Q_EMIT presentStateChanged(m_isPresent, m_device.data()->udi());
         }
 
         if (old_chargePercent != m_chargePercent) {
-            emit chargePercentChanged(m_chargePercent, m_device.data()->udi());
+            Q_EMIT chargePercentChanged(m_chargePercent, m_device.data()->udi());
         }
 
         if (old_capacity != m_capacity) {
-            emit capacityChanged(m_capacity, m_device.data()->udi());
+            Q_EMIT capacityChanged(m_capacity, m_device.data()->udi());
         }
 
         if (old_isPowerSupply != m_isPowerSupply) {
-            emit powerSupplyStateChanged(m_isPowerSupply, m_device.data()->udi());
+            Q_EMIT powerSupplyStateChanged(m_isPowerSupply, m_device.data()->udi());
         }
 
         if (old_chargeState != m_chargeState) {
-            emit chargeStateChanged(m_chargeState, m_device.data()->udi());
+            Q_EMIT chargeStateChanged(m_chargeState, m_device.data()->udi());
         }
 
         if (old_timeToEmpty != m_timeToEmpty) {
-            emit timeToEmptyChanged(m_timeToEmpty, m_device.data()->udi());
+            Q_EMIT timeToEmptyChanged(m_timeToEmpty, m_device.data()->udi());
         }
 
         if (old_timeToFull != m_timeToFull) {
-            emit timeToFullChanged(m_timeToFull, m_device.data()->udi());
+            Q_EMIT timeToFullChanged(m_timeToFull, m_device.data()->udi());
         }
 
         if (old_energy != m_energy) {
-            emit energyChanged(m_energy, m_device.data()->udi());
+            Q_EMIT energyChanged(m_energy, m_device.data()->udi());
         }
 
         if (old_energyFull != m_energyFull) {
-            emit energyFullChanged(m_energyFull, m_device.data()->udi());
+            Q_EMIT energyFullChanged(m_energyFull, m_device.data()->udi());
         }
 
         if (old_energyFullDesign != m_energyFullDesign) {
-            emit energyFullChanged(m_energyFullDesign, m_device.data()->udi());
+            Q_EMIT energyFullChanged(m_energyFullDesign, m_device.data()->udi());
         }
 
         if (old_energyRate != m_energyRate) {
-            emit energyRateChanged(m_energyRate, m_device.data()->udi());
+            Q_EMIT energyRateChanged(m_energyRate, m_device.data()->udi());
         }
 
         if (old_voltage != m_voltage) {
-            emit voltageChanged(m_voltage, m_device.data()->udi());
+            Q_EMIT voltageChanged(m_voltage, m_device.data()->udi());
         }
 
         if (old_temperature != m_temperature) {
-            emit temperatureChanged(m_temperature, m_device.data()->udi());
+            Q_EMIT temperatureChanged(m_temperature, m_device.data()->udi());
         }
 
         if (old_timeToFull != m_timeToFull || old_timeToEmpty != m_timeToEmpty) {
-            emit remainingTimeChanged(remainingTime(), m_device.data()->udi());
+            Q_EMIT remainingTimeChanged(remainingTime(), m_device.data()->udi());
         }
     }
 }
