@@ -1,37 +1,27 @@
 /*  This file is part of the KDE project
-    Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
-    Copyright (C) 2014 Alejandro Fiestas Olivares <afiestas@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 2006 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2014 Alejandro Fiestas Olivares <afiestas@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "solid-hardware.h"
 
 
+#if defined QT_DBUS_LIB
+#include <QDBusArgument>
+#include <QDBusObjectPath>
+#endif
 #include <QString>
 #include <QStringList>
 #include <QMetaProperty>
 #include <QMetaEnum>
+#include <QTextStream>
 
-#include <QCoreApplication>
 #include <QCommandLineParser>
 
 #include <solid/device.h>
 #include <solid/genericinterface.h>
-#include <solid/storageaccess.h>
 #include <solid/opticaldrive.h>
 
 #include <iostream>
@@ -47,6 +37,58 @@ std::ostream &operator<<(std::ostream &out, const QString &msg)
     return (out << msg.toLocal8Bit().constData());
 }
 
+std::ostream &operator<<(std::ostream &out, const QVariant &value);
+#if defined QT_DBUS_LIB
+std::ostream &operator<<(std::ostream &out, const QDBusArgument &arg)
+{
+    auto type = arg.currentType();
+    switch (type) {
+    case QDBusArgument::ArrayType:
+        out << " { ";
+        arg.beginArray();
+        while (!arg.atEnd()) {
+            out << arg;
+            if (!arg.atEnd()) {
+                out << ", ";
+            }
+        }
+        arg.endArray();
+        out << " }";
+        break;
+    case QDBusArgument::StructureType:
+        out << " ( ";
+        arg.beginStructure();
+        while (!arg.atEnd()) {
+            out << arg.asVariant();
+        }
+        arg.endStructure();
+        out << " )";
+        break;
+    case QDBusArgument::MapType:
+        out << " [ ";
+        arg.beginMap();
+        if (!arg.atEnd()) {
+            out << arg;
+        }
+        arg.endMap();
+        out << " ]";
+        break;
+    case QDBusArgument::MapEntryType:
+        arg.beginMapEntry();
+        out << arg.asVariant() << " = " << arg;
+        arg.endMapEntry();
+        break;
+    case QDBusArgument::UnknownType:
+        out << "(unknown DBus type)";
+        break;
+    case QDBusArgument::BasicType:
+    case QDBusArgument::VariantType:
+        out << arg.asVariant();
+    }
+    return out;
+}
+#endif
+
 std::ostream &operator<<(std::ostream &out, const QVariant &value)
 {
     switch (value.type())
@@ -70,11 +112,14 @@ std::ostream &operator<<(std::ostream &out, const QVariant &value)
             }
         }
 
-        out << "}  (string list)";
+        out << "} (string list)";
         break;
     }
+    case QVariant::String:
+        out << "'" << value.toString() << "' (string)";
+        break;
     case QVariant::Bool:
-        out << (value.toBool()?"true":"false") << "  (bool)";
+        out << (value.toBool()?"true":"false") << " (bool)";
         break;
     case QVariant::Int:
     case QVariant::LongLong:
@@ -89,21 +134,34 @@ std::ostream &operator<<(std::ostream &out, const QVariant &value)
     case QVariant::Double:
         out << value.toString() << " (double)";
         break;
+    case QVariant::ByteArray:
+        out << "'" << value.toString() << "' (bytes)";
+        break;
     case QVariant::UserType:
-    {
         //qDebug() << "got variant type:" << value.typeName();
         if (value.canConvert<QList<int> >())
         {
-            QList<int> intlist = value.value<QList<int> >();
+            const QList<int> intlist = value.value<QList<int>>();
             QStringList tmp;
-            foreach (int val, intlist)
+            for (const int val : intlist) {
                 tmp.append(QString::number(val));
+            }
             out << "{" << tmp.join(",") << "} (int list)";
+#if defined QT_DBUS_LIB
+        } else if (value.canConvert<QDBusObjectPath>()) {
+            out << value.value<QDBusObjectPath>().path() << " (ObjectPath)";
+        } else if (value.canConvert<QDBusVariant>()) {
+            out << value.value<QDBusVariant>().variant() << "(Variant)";
+        } else if (value.canConvert<QDBusArgument>()) {
+            out << value.value<QDBusArgument>();
+#endif
+        } else {
+            out << value.toString() << " (unhandled)";
         }
+
         break;
-    }
     default:
-        out << "'" << value.toString() << "'  (string)";
+        out << "'" << value.toString() << "' (" << QVariant::typeToName(value.type()) << ")";
         break;
     }
 
@@ -160,9 +218,8 @@ std::ostream &operator<<(std::ostream &out, const Solid::Device &device)
 
 std::ostream &operator<<(std::ostream &out, const QMap<QString,QVariant> &properties)
 {
-    Q_FOREACH (const QString &key, properties.keys())
-    {
-        out << "  " << key << " = " << properties[key] << endl;
+    for (auto it = properties.cbegin(); it != properties.cend(); ++it) {
+        out << "  " << it.key() << " = " << it.value() << endl;
     }
 
     return out;
@@ -178,6 +235,59 @@ QString getUdiFromArguments(QCoreApplication &app, QCommandLineParser &parser)
     return parser.positionalArguments().at(1);
 }
 
+static QString commandsHelp()
+{
+    QString data;
+    QTextStream cout(&data);
+    cout << '\n' << QCoreApplication::translate("solid-hardware", "Syntax:") << '\n' << '\n';
+
+    cout << "  solid-hardware list [details|nonportableinfo]" << '\n';
+    cout << QCoreApplication::translate("solid-hardware",
+            "             # List the hardware available in the system.\n"
+            "             # - If the 'nonportableinfo' option is specified, the device\n"
+            "             # properties are listed (be careful, in this case property names\n"
+            "             # are backend dependent),\n"
+            "             # - If the 'details' option is specified, the device interfaces\n"
+            "             # and the corresponding properties are listed in a platform\n"
+            "             # neutral fashion,\n"
+            "             # - Otherwise only device UDIs are listed.\n") << '\n';
+
+    cout << "  solid-hardware details 'udi'" << '\n';
+    cout << QCoreApplication::translate("solid-hardware",
+            "             # Display all the interfaces and properties of the device\n"
+            "             # corresponding to 'udi' in a platform neutral fashion.\n") << '\n';
+
+    cout << "  solid-hardware nonportableinfo 'udi'" << '\n';
+    cout << QCoreApplication::translate("solid-hardware",
+            "             # Display all the properties of the device corresponding to 'udi'\n"
+            "             # (be careful, in this case property names are backend dependent).\n") << '\n';
+
+    cout << "  solid-hardware query 'predicate' ['parentUdi']" << '\n';
+    cout << QCoreApplication::translate("solid-hardware",
+            "             # List the UDI of devices corresponding to 'predicate'.\n"
+            "             # - If 'parentUdi' is specified, the search is restricted to the\n"
+            "             # branch of the corresponding device,\n"
+            "             # - Otherwise the search is done on all the devices.\n") << '\n';
+
+    cout << "  solid-hardware mount 'udi'" << '\n';
+    cout << QCoreApplication::translate("solid-hardware",
+            "             # If applicable, mount the device corresponding to 'udi'.\n") << '\n';
+
+    cout << "  solid-hardware unmount 'udi'" << '\n';
+    cout << QCoreApplication::translate("solid-hardware",
+            "             # If applicable, unmount the device corresponding to 'udi'.\n") << '\n';
+
+    cout << "  solid-hardware eject 'udi'" << '\n';
+    cout << QCoreApplication::translate("solid-hardware",
+            "             # If applicable, eject the device corresponding to 'udi'.\n") << '\n';
+
+    cout << "  solid-hardware listen" << '\n';
+    cout << QCoreApplication::translate("solid-hardware",
+            "             # Listen to all add/remove events on supported hardware.") << '\n';
+
+    return data;
+}
+
 int main(int argc, char **argv)
 {
     SolidHardware app(argc, argv);
@@ -188,60 +298,18 @@ int main(int argc, char **argv)
     parser.setApplicationDescription(QCoreApplication::translate("solid-hardware", "KDE tool for querying your hardware from the command line"));
     parser.addHelpOption();
     parser.addVersionOption();
-    parser.addPositionalArgument("command", QCoreApplication::translate("solid-hardware", "Command to execute"));
+    parser.addPositionalArgument("command", QCoreApplication::translate("solid-hardware", "Command to execute"), commandsHelp());
 
     QCommandLineOption commands("commands", QCoreApplication::translate("solid-hardware", "Show available commands"));
+    // --commands only for backwards compat, it's now in the "syntax help"
+    // of the positional argument.
+    commands.setFlags(QCommandLineOption::HiddenFromHelp);
     parser.addOption(commands);
 
     parser.process(app);
     if (parser.isSet(commands))
     {
-        cout << endl << QCoreApplication::translate("solid-hardware", "Syntax:") << endl << endl;
-
-        cout << "  solid-hardware list [details|nonportableinfo]" << endl;
-        cout << QCoreApplication::translate("solid-hardware",
-                "             # List the hardware available in the system.\n"
-                "             # - If the 'nonportableinfo' option is specified, the device\n"
-                "             # properties are listed (be careful, in this case property names\n"
-                "             # are backend dependent),\n"
-                "             # - If the 'details' option is specified, the device interfaces\n"
-                "             # and the corresponding properties are listed in a platform\n"
-                "             # neutral fashion,\n"
-                "             # - Otherwise only device UDIs are listed.\n") << endl;
-
-        cout << "  solid-hardware details 'udi'" << endl;
-        cout << QCoreApplication::translate("solid-hardware",
-                "             # Display all the interfaces and properties of the device\n"
-                "             # corresponding to 'udi' in a platform neutral fashion.\n") << endl;
-
-        cout << "  solid-hardware nonportableinfo 'udi'" << endl;
-        cout << QCoreApplication::translate("solid-hardware",
-                "             # Display all the properties of the device corresponding to 'udi'\n"
-                "             # (be careful, in this case property names are backend dependent).\n") << endl;
-
-        cout << "  solid-hardware query 'predicate' ['parentUdi']" << endl;
-        cout << QCoreApplication::translate("solid-hardware",
-                "             # List the UDI of devices corresponding to 'predicate'.\n"
-                "             # - If 'parentUdi' is specified, the search is restricted to the\n"
-                "             # branch of the corresponding device,\n"
-                "             # - Otherwise the search is done on all the devices.\n") << endl;
-
-        cout << "  solid-hardware mount 'udi'" << endl;
-        cout << QCoreApplication::translate("solid-hardware",
-                "             # If applicable, mount the device corresponding to 'udi'.\n") << endl;
-
-        cout << "  solid-hardware unmount 'udi'" << endl;
-        cout << QCoreApplication::translate("solid-hardware",
-                "             # If applicable, unmount the device corresponding to 'udi'.\n") << endl;
-
-        cout << "  solid-hardware eject 'udi'" << endl;
-        cout << QCoreApplication::translate("solid-hardware",
-                "             # If applicable, eject the device corresponding to 'udi'.\n") << endl;
-
-        cout << "  solid-hardware listen" << endl;
-        cout << QCoreApplication::translate("solid-hardware",
-                "             # Listen to all add/remove events on supported hardware.") << endl;
-
+        cout << commandsHelp() << endl;
         return 0;
     }
 
@@ -307,7 +375,7 @@ bool SolidHardware::hwList(bool interfaces, bool system)
 {
     const QList<Solid::Device> all = Solid::Device::allDevices();
 
-    Q_FOREACH (const Solid::Device &device, all)
+    for (const Solid::Device &device : all)
     {
         cout << "udi = '" << device.udi() << "'" << endl;
 
@@ -353,8 +421,7 @@ bool SolidHardware::hwQuery(const QString &parentUdi, const QString &query)
     const QList<Solid::Device> devices
         = Solid::Device::listFromQuery(query, parentUdi);
 
-    Q_FOREACH (const Solid::Device &device, devices)
-    {
+    for (const Solid::Device &device : devices) {
         cout << "udi = '" << device.udi() << "'" << endl;
     }
 
